#include <iostream>
#include <vector>
#include <queue>
#include <tuple> //   tie()
#include <numeric>

using namespace std;

//    (i, j)  
bool isLand(int i, int j) {
    return (i & j) == 0;
}

// BFS       
void bfs(int startX, int startY, int a, int b, int c, int d, vector<vector<bool>>& visited) {
    int directions[4][2] = {{0, 1}, {1, 0}, {0, -1}, {-1, 0}};
    queue<pair<int, int>> q;
    q.push({startX, startY});
    visited[startX - a][startY - b] = true;

    while (!q.empty()) {
        auto [x, y] = q.front();
        q.pop();

        for (auto& dir : directions) {
            int nx = x + dir[0], ny = y + dir[1];
            if (nx >= a && nx <= c && ny >= b && ny <= d && isLand(nx, ny) && !visited[nx - a][ny - b]) {
                visited[nx - a][ny - b] = true;
                q.push({nx, ny});
            }
        }
    }
}

//      
vector<int> countIslands(int n, int m, int q, vector<tuple<int, int, int, int>>& queries) {
    vector<int> results;

    for (auto& query : queries) {
        int a, b, c, d;
        tie(a, b, c, d) = query;

        int rows = c - a + 1;
        int cols = d - b + 1;

        vector<vector<bool>> visited(rows, vector<bool>(cols, false));
        int islands = 0;

        for (int i = a; i <= c; ++i) {
            for (int j = b; j <= d; ++j) {
                if (isLand(i, j) && !visited[i - a][j - b]) {
                    islands++;
                    bfs(i, j, a, b, c, d, visited);
                }
            }
        }

        results.push_back(islands);
    }

    return results;
}

int main() {
    int n, m, q;
    cin >> n >> m >> q;

    vector<tuple<int, int, int, int>> queries(q);
    for (int i = 0; i < q; ++i) {
        int a, b, c, d;
        cin >> a >> b >> c >> d;
        queries[i] = {a, b, c, d};
    }

    vector<int> results = countIslands(n, m, q, queries);
    for (int result : results) {
        cout << result << endl;
    }

    return 0;
}

