#include <iostream>
#include <vector>
#include <tuple>
#include <unordered_map>
#include <numeric>

using namespace std;

const int MAX_DIM = 2000; //   

// Union-Find 
class UnionFind {
public:
    vector<int> parent, rank;

    UnionFind(int n) {
        parent.resize(n);
        rank.resize(n, 0);
        iota(parent.begin(), parent.end(), 0); //    
    }

    int find(int x) {
        if (parent[x] != x) {
            parent[x] = find(parent[x]); //  
        }
        return parent[x];
    }

    void unite(int x, int y) {
        int rootX = find(x);
        int rootY = find(y);
        if (rootX != rootY) {
            if (rank[rootX] > rank[rootY]) {
                parent[rootY] = rootX;
            } else if (rank[rootX] < rank[rootY]) {
                parent[rootX] = rootY;
            } else {
                parent[rootY] = rootX;
                rank[rootX]++;
            }
        }
    }
};

//    (i, j)  
bool isLand(int i, int j) {
    return (i & j) == 0;
}

int countIslands(int a, int b, int c, int d) {
    int rows = c - a + 1;
    int cols = d - b + 1;

    vector<vector<int>> id(rows, vector<int>(cols, -1)); //  ID   
    UnionFind uf(rows * cols);

    auto getId = [&](int x, int y) { return (x - a) * cols + (y - b); };

    //  ID   
    for (int i = a; i <= c; ++i) {
        for (int j = b; j <= d; ++j) {
            if (isLand(i, j)) {
                id[i - a][j - b] = getId(i, j);
                //    
                if (i > a && isLand(i - 1, j)) {
                    uf.unite(getId(i, j), getId(i - 1, j));
                }
                //    
                if (j > b && isLand(i, j - 1)) {
                    uf.unite(getId(i, j), getId(i, j - 1));
                }
            }
        }
    }

    //    
    unordered_map<int, bool> uniqueRoots;
    for (int i = a; i <= c; ++i) {
        for (int j = b; j <= d; ++j) {
            if (isLand(i, j)) {
                int root = uf.find(getId(i, j));
                uniqueRoots[root] = true;
            }
        }
    }

    return uniqueRoots.size(); //    
}

int main() {
    int n, m, q;
    cin >> n >> m >> q;

    vector<tuple<int, int, int, int>> queries(q);
    for (int i = 0; i < q; ++i) {
        int a, b, c, d;
        cin >> a >> b >> c >> d;
        queries[i] = {a, b, c, d};
    }

    for (auto& query : queries) {
        int a, b, c, d;
        tie(a, b, c, d) = query;
        cout << countIslands(a, b, c, d) << endl;
    }

    return 0;
}

