#include <iostream>
#include <vector>
#include <queue>
#include <unordered_set>
#include <algorithm>

using namespace std;

// BFS  -    ( 1)
vector<int> bfs(int start, const vector<vector<int>>& graph, int n) {
    vector<int> distance(n + 1, -1);
    queue<int> q;

    distance[start] = 0;
    q.push(start);

    while (!q.empty()) {
        int node = q.front();
        q.pop();

        for (int neighbor : graph[node]) {
            if (distance[neighbor] == -1) { //    
                distance[neighbor] = distance[node] + 1;
                q.push(neighbor);
            }
        }
    }

    return distance;
}

// DFS      
void dfs(int node, const vector<vector<int>>& graph, vector<bool>& visited, vector<int>& component) {
    visited[node] = true;
    component.push_back(node);

    for (int neighbor : graph[node]) {
        if (!visited[neighbor]) {
            dfs(neighbor, graph, visited, component);
        }
    }
}

//  
int findMinimumNewEdges(int n, const vector<pair<int, int>>& edges) {
    //  
    vector<vector<int>> graph(n + 1);
    for (const auto& [u, v] : edges) {
        graph[u].push_back(v);
        graph[v].push_back(u);
    }

    //   -   
    vector<int> distance = bfs(1, graph, n);

    //     
    vector<bool> visited(n + 1, false);
    vector<vector<int>> components;

    for (int i = 1; i <= n; ++i) {
        if (!visited[i]) {
            vector<int> component;
            dfs(i, graph, visited, component);
            components.push_back(component);
        }
    }

    //     ,    
    if (components.size() == 1) {
        return 0;
    }

    //  
    int newEdges = 0;
    unordered_set<int> connectedComponents;

    for (const auto& component : components) {
        bool isConnected = false;
        for (int node : component) {
            if (distance[node] != -1) {
                isConnected = true;
                break;
            }
        }

        if (!isConnected) {
            newEdges++;
        }
    }

    return newEdges;
}

int main() {
    int n, m;
    cin >> n >> m;

    vector<pair<int, int>> edges(m);
    for (int i = 0; i < m; ++i) {
        int u, v;
        cin >> u >> v;
        edges[i] = {u, v};
    }

    int result = findMinimumNewEdges(n, edges);
    cout << result << endl;

    return 0;
}

