#include <iostream>
#include <vector>
#include <algorithm>
using namespace std;

const int MAX_N = 200000;

int n;
vector<pair<int, int>> sections;
int parent[MAX_N], rank_[MAX_N];
long long water_sum[MAX_N];
int size_[MAX_N];

int find(int x){
    if(parent[x] != x){
        parent[x] = find(parent[x]);
    }
    return parent[x];
}

void union_set(int x, int y){
    int root_x = find(x);
    int root_y = find(y);

    if(root_x != root_y){
        if(rank_[root_x] < rank_[root_y]){
            swap(root_x, root_y);
        } else if(rank_[root_x] == rank_[root_y]){
            rank_[root_x] ++;
        }

        parent[root_y] = root_x;
        size_[root_x] += size_[root_y];
        water_sum[root_x] += water_sum[root_y];
    }
}

void read(){
    cin >> n;
    sections.resize(n);
    for(int i = 0; i < n; i++){
        int h;
        cin >> h;
        sections[i] = {h, i+1};
        parent[i] = i;
        rank_[i] = 0;
        water_sum[i] = h;
        size_[i] = 1;
    }
}

void solve(){
    sort(sections.begin(), sections.end());

    vector<int> order;
    vector<int> u(n, 0);

    for(int i = 0; i < n; i++) {
        u[sections[i].second] = 1;

        if(sections[i].second > 0 && u[sections[i].second - 1]){
            union_set(sections[i].second, sections[i].second - 1);
        }

        if(sections[i].second < n-1 && u[sections[i].second + 1]){
            union_set(sections[i].second, sections[i].second + 1);
        }

        int root = find(sections[i].second);
        double avg_height = (double)water_sum[root]/size_[root];

        if(avg_height > sections[i].first) {
            cout << "impossible";
            return;
        }

        order.push_back(sections[i].second + 1);
    }

    for(int i = 0; i < order.size(); i++){
        if(i == order.size() - 1) cout << order[i];
        else cout << order[i] << ' ';
    }
}

int main(){
    read();
    solve();
    return 0;
}